@@ -471,11 +471,12 @@ def test_create_project(config_from_file, project_proxy_add, capsys):
         "unlisted_on_hp": None, "devel_mode": None, "enable_net": False,
         "bootstrap": "default",
         'isolation': 'default',
+        "follow_fedora_branching": True,
         "delete_after_days": None,
         "multilib": False,
         "module_hotfixes": False,
         "fedora_review": False,
-        "appstream": True,
+        "appstream": False,
         "runtime_dependencies": None,
         "packit_forge_projects_allowed": None,
     }
@@ -566,22 +567,26 @@ def test_create_multilib_project(config_from_file, project_proxy_add, capsys):
         "unlisted_on_hp": None, "devel_mode": None, "enable_net": False,
         'bootstrap': 'default',
         'isolation': 'default',
+        "follow_fedora_branching": True,
         "delete_after_days": None,
         "multilib": True,
         "module_hotfixes": False,
         "fedora_review": False,
-        "appstream": True,
+        "appstream": False,
         "runtime_dependencies": None,
         "packit_forge_projects_allowed": None,
     }
     assert stdout == "New project was successfully created: http://copr/coprs/jdoe/foo/\n"
 
 
+@mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+            return_value=True)
 @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
 @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
 @mock.patch('copr_cli.main.Commands._watch_builds')
-def test_create_build_no_wait_ok(watch_builds, config_from_file, create_from_url, auth_check, capsys):
+def test_create_build_no_wait_ok(watch_builds, config_from_file,
+                                 create_from_url, auth_check, _can_build_in, capsys):
     create_from_url.return_value = Munch(projectname="foo", id=123)
 
     main.main(argv=[
@@ -595,11 +600,15 @@ def test_create_build_no_wait_ok(watch_builds, config_from_file, create_from_url
     assert not watch_builds.called
 
 
+@mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+            return_value=True)
 @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
 @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
 @mock.patch('copr_cli.main.Commands._watch_builds')
-def test_create_build_no_wait_error(watch_builds, config_from_file,create_from_url, autch_check, capsys):
+def test_create_build_no_wait_error(watch_builds, config_from_file,
+                                    create_from_url, autch_check, _can_build_in,
+                                    capsys):
     response_message = "foobar"
     create_from_url.side_effect = copr.v3.CoprRequestException(response_message)
 
@@ -615,12 +624,15 @@ def test_create_build_no_wait_error(watch_builds, config_from_file,create_from_u
 
 
 @mock.patch('copr_cli.main.time')
+@mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+            return_value=True)
 @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
 @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
 @mock.patch('copr.v3.proxies.build.BuildProxy.get')
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
 def test_create_build_wait_succeeded_no_sleep(config_from_file, build_proxy_get,
-                                              create_from_url, auth_check, mock_time, capsys):
+                                              create_from_url, auth_check,
+                                              _can_build_in, mock_time, capsys):
     create_from_url.return_value = Munch(projectname="foo", id=123)
     build_proxy_get.return_value = Munch(state="succeeded")
     main.main(argv=[
@@ -634,11 +646,15 @@ def test_create_build_wait_succeeded_no_sleep(config_from_file, build_proxy_get,
     assert not mock_time.sleep.called
 
 
+@mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+            return_value=True)
 @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
 @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
 @mock.patch('copr.v3.proxies.build.BuildProxy.get')
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
-def test_create_build_wait_error_status(config_from_file, build_proxy_get, create_from_url, auth_check, capsys):
+def test_create_build_wait_error_status(config_from_file, build_proxy_get,
+                                        create_from_url, auth_check,
+                                        _can_build_in, capsys):
     create_from_url.return_value = Munch(projectname="foo", id=123)
     build_proxy_get.side_effect = copr.v3.CoprRequestException()
     with pytest.raises(SystemExit) as err:
@@ -653,11 +669,15 @@ def test_create_build_wait_error_status(config_from_file, build_proxy_get, creat
     assert "Watching build" in stdout
 
 
+@mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+            return_value=True)
 @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
 @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
 @mock.patch('copr.v3.proxies.build.BuildProxy.get')
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
-def test_create_build_wait_unknown_build_status(config_from_file, build_proxy_get, create_from_url, auth_check, capsys):
+def test_create_build_wait_unknown_build_status(config_from_file, build_proxy_get,
+                                                create_from_url, auth_check,
+                                                _can_build_in, capsys):
     create_from_url.return_value = Munch(projectname="foo", id=123)
     build_proxy_get.return_value = Munch(state="unknown")
     with pytest.raises(SystemExit) as err:
@@ -672,11 +692,15 @@ def test_create_build_wait_unknown_build_status(config_from_file, build_proxy_ge
     assert "Watching build" in stdout
 
 
+@mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+            return_value=True)
 @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
 @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
 @mock.patch('copr.v3.proxies.build.BuildProxy.get')
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
-def test_create_build_wait_keyboard_interrupt(config_from_file, build_proxy_get, create_from_url, autch_check, capsys):
+def test_create_build_wait_keyboard_interrupt(config_from_file, build_proxy_get,
+                                              create_from_url, autch_check,
+                                              _can_build_in, capsys):
     create_from_url.return_value = Munch(projectname="foo", id=123)
     build_proxy_get.side_effect = KeyboardInterrupt
 
@@ -694,11 +718,15 @@ def test_create_build_wait_keyboard_interrupt(config_from_file, build_proxy_get,
 @mock.patch('copr_cli.main.config_from_file', return_value=mock_config)
 class TestCreateBuild(object):
 
+    @mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+                return_value=True)
     @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
     @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
     @mock.patch('copr.v3.proxies.build.BuildProxy.get')
-    def test_create_build_wait_succeeded_complex(self, build_proxy_get, create_from_url, auth_check,
-                                                 config_from_file, mock_time, capsys):
+    def test_create_build_wait_succeeded_complex(self, build_proxy_get,
+                                                 create_from_url, auth_check,
+                                                 _can_build_in, config_from_file,
+                                                 mock_time, capsys):
         create_from_url.return_value = Munch(projectname="foo", id=1)
         self.stage = 0
 
@@ -731,11 +759,15 @@ class TestCreateBuild(object):
         assert "Watching build" in stdout
         assert len(mock_time.sleep.call_args_list) == 3
 
+    @mock.patch('copr.v3.proxies.project.ProjectProxy.can_build_in',
+                return_value=True)
     @mock.patch('copr.v3.proxies.BaseProxy.auth_check', return_value=Munch(name="test"))
     @mock.patch('copr.v3.proxies.build.BuildProxy.create_from_url')
     @mock.patch('copr.v3.proxies.build.BuildProxy.get')
-    def test_create_build_wait_failed_complex(self, build_proxy_get, create_from_url, auth_check,
-                                              config_from_file, mock_time, capsys):
+    def test_create_build_wait_failed_complex(self, build_proxy_get,
+                                              create_from_url, auth_check,
+                                              _can_build_in, config_from_file,
+                                              mock_time, capsys):
         create_from_url.return_value = Munch(projectname="foo", id=1)
         self.stage = 0
 
@@ -868,3 +900,16 @@ def test_module_build(config, patch_name, args):
             assert kwargs['distgit'] == args[1]
         else:
             assert kwargs['distgit'] is None
+
+
+@responses.activate
+@mock.patch("copr_cli.main.config_from_file", return_value=mock_config)
+@mock.patch("copr.v3.proxies.project.ProjectProxy.get")
+def test_get_project(mock_get, config_from_file, capsys):  # pylint: disable=unused-argument
+    response_data = json.loads(read_res("get_project_response.json"))
+    expected_output = read_res("get_project_expected.txt")
+
+    mock_get.return_value = Munch(response_data)
+    main.main(argv=["get", "rhscl/ruby193"])
+    out, _ = capsys.readouterr()
+    assert expected_output in out
